#!/usr/bin/env python3

"""Dumps to standard output all information on a particular eddy,
specified by date and intra-date eddy index, or by inter-date eddy
index, or by shape index assuming slice 0.

"""

import argparse
import pprint

import shapefile

import util_eddies

parser = argparse.ArgumentParser()
parser.add_argument("directory", metavar="SHPC-directory")
parser.add_argument("orientation", choices=["Anticyclones", "Cyclones"])
group = parser.add_mutually_exclusive_group()
group.add_argument("-i", "--ishape", type=int)
group.add_argument("-n", "--node", type=int)
args = parser.parse_args()
SHPC = util_eddies.SHPC_class(args.directory, def_orient=args.orientation)

if args.ishape:
    ishape = args.ishape
    i_slice = 0
else:
    if args.node:
        with open("e_overestim.txt") as f:
            e_overestim = int(f.read())
        date, eddy_index = util_eddies.node_to_date_eddy(args.node, e_overestim)
    else:
        reply = input("date, eddy_index = ? ").split(",")
        date = int(reply[0])
        eddy_index = int(reply[1])
        assert eddy_index >= 1

    i_slice, ishape = SHPC.comp_ishape(date, eddy_index, args.orientation)

print("ishape =", ishape)

for layer in ["extremum", "outermost_contour", "max_speed_contour", "centroid"]:
    print()

    try:
        shapeRec = SHPC.get_reader(
            i_slice, args.orientation, layer
        ).shapeRecord(ishape)
    except AttributeError:
        pass
    else:
        print(layer, ":")

        if shapeRec.shape.shapeType == shapefile.NULL:
            dct = shapeRec.record.as_dict()
            pprint.pprint(dct)
            print("null shape")
        else:
            pprint.pprint(shapeRec.__geo_interface__)
