#!/usr/bin/env python3

import netCDF4
import matplotlib.pyplot as plt
import numpy as np
import math
import argparse

parser = argparse.ArgumentParser()
parser.add_argument("SSH_file", help = "NetCDF")
parser.add_argument("--save", "-s", action = "store_true")
args = parser.parse_args()

with netCDF4.Dataset(args.SSH_file) as f:
    ssh = f.variables["adt"][:].squeeze()
    longitude = f["longitude"][:]
    latitude = f["latitude"][:]

lon_center = float(input("longitude of center (same unit as input file) = ? "))
lat_center = float(input("latitude of center (same unit as input file) = ? "))

# Base 0 indices, assuming regular grid::
i_center = round(float((lon_center - longitude[0])
                       / (longitude[1] - longitude[0])))
j_center = round(float((lat_center - latitude[0])
                       / (latitude[1] - latitude[0])))
# (float to convert from numpy.float64, so that round produces an int)

level = float(input("level = ? "))

plt.figure()
plt.contour(longitude, latitude, ssh, (level,))
delta = 4
lon_2d, lat_2d = np.meshgrid(longitude[i_center - delta:i_center + delta + 1],
                             latitude[j_center - delta:j_center + delta + 1])
plt.plot(lon_2d.reshape(-1), lat_2d.reshape(-1), "+")
plt.plot(longitude[i_center], latitude[j_center], "o", markersize = 10,
         fillstyle = "none")

for i in np.arange(i_center - delta,i_center + delta + 1):
    for j in np.arange(j_center - delta,j_center + delta + 1):
        if 0 <= i < longitude.size and 0 <= j < latitude.size:
            plt.annotate(ssh[j,i], (longitude[i], latitude[j]))

if args.save:
    plt.savefig("examine_ssh_values.png")
    print('Created file "examine_ssh_values.png".')
else:
    plt.show()
