#!/usr/bin/env python3

import argparse
from os import path

import shapefile
import numpy as np

parser = argparse.ArgumentParser()
parser.add_argument("SHPC")
parser.add_argument("orientation", choices=["Anticyclones", "Cyclones"])
args = parser.parse_args()

n_points = 0
n_valid_speed = 0

with shapefile.Reader(
    path.join(args.SHPC, "Slice_0", args.orientation, "extremum")
) as extremum, shapefile.Reader(
    path.join(args.SHPC, "Slice_0", args.orientation, "outermost_contour")
) as outermost_contour:
    n_extr = len(extremum)
    print("number of extrema of SSH:", n_extr, "\n")
    field_names_outer = [f[0] for f in outermost_contour.fields[1:]]

    for rec_extr, shape_rec_outer in zip(
        extremum.iterRecords(), outermost_contour
    ):
        l = len(shape_rec_outer.shape.points)
        n_points += l

        if rec_extr.speed != 1e4:
            n_valid_speed += 1

print(
    "average number of points of outermost contour per extremum:",
    n_points / n_extr,
    "\n",
)
print("number of valid speed values:", n_valid_speed)

n_max_speed = 0
n_points = 0

with shapefile.Reader(
    path.join(args.SHPC, "Slice_0", args.orientation, "max_speed_contour")
) as max_speed_contour:
    for shape_rec in max_speed_contour:
        l = len(shape_rec.shape.points)

        if shape_rec.record.r_eq_area >= 0:
            n_max_speed += 1
            n_points += l

print(
    "number of non-null maximum-speed contours (distinct from the "
    "outermost contour):",
    n_max_speed,
)

if n_max_speed != 0:
    print(
        "average number of points of non-null maximum-speed contours:",
        n_points / n_max_speed,
    )
