#!/usr/bin/env python3

import netCDF4
import cartopy.crs as ccrs
import jumble
from matplotlib import pyplot as plt
import glob
import itertools

plt.figure()
ax = plt.axes(projection=ccrs.PlateCarree())
colors = itertools.cycle(['blue', 'orange', 'green', 'red', 'purple', 'brown',
                          'pink', 'gray', 'olive', 'cyan'])

for filename in glob.glob("h_region_*.nc") + ["h_outermost.nc"]:
    with netCDF4.Dataset(filename) as f:
        if "lon" in f.variables:
            lon = "lon"
            lat = "lat"
        else:
            lon = "longitude"
            lat = "latitude"
            
        jumble.draw_bbox(f[lon][0], f[lon][-1], f[lat][0], f[lat][-1],
                         colors = next(colors), label = filename)

jumble.draw_bbox(5.125, 12.125, -36.375, -32.375, colors = next(colors),
                 label = "region 1")
jumble.draw_bbox(5.875, 5.875 + 25 * 0.25, -32.125, -32.125 + 21 * 0.25,
                 colors = next(colors), label = "region 6")

ax.set_extent((-30, 60, -90, 0), ccrs.PlateCarree())
ax.coastlines()
ax.gridlines(draw_labels = True)
plt.legend(loc = "lower left", bbox_to_anchor = (1, 0.5))
plt.subplots_adjust(right = 0.7)
plt.savefig("regions.pdf")
##plt.show()
