#!/usr/bin/env python3

import pandas as pd
import matplotlib.pyplot as plt
import numpy as np

def timedelta2h(x):
    return pd.Timedelta(x).total_seconds() / 3600

resources_used = pd.read_csv("resources_used.csv", skiprows = 2,
                             delim_whitespace = True, index_col = 0,
                             converters = {"cput": timedelta2h,
                                           "walltime": timedelta2h,
                                           "real": timedelta2h,
                                           "user": timedelta2h,
                                           "sys": timedelta2h})
n_years = len(resources_used)
walltime_sorted = resources_used.walltime.sort_values().to_numpy()
cput_sorted = resources_used.cput.sort_values().to_numpy()
index = np.arange(1, n_years + 1) / n_years

# Plot distribution functions:
fig, ax = plt.subplots()
ax.plot(walltime_sorted, index, label = "walltime")
ax.plot(cput_sorted, index, label = "cput")
ax.legend()
ax.set_xlabel("time, in h")
ax.set_ylabel("distribution function")
##fig.savefig("distribution.pdf")

# cput vs sleep:
resources_used["sleep"] = resources_used.walltime - resources_used.cput
resources_used.plot(x = "cput", y = "sleep", style = "o")
plt.xlabel("cput, in h")
plt.ylabel("sleep time, in h")
plt.savefig("cput_sleep.pdf")

# walltime, sleep, user and sys:
resources_used[["walltime", "sleep", "user", "sys"]].plot()
plt.ylabel("time, in h")
plt.ylim(bottom = 0)
plt.savefig("user_sys.pdf")

# user grouped by proc:
fig, ax = plt.subplots()
resources_used.groupby("proc").user.plot(style = "o", ax = ax)
ax.set_ylabel("CPU user time, in h")
ax.legend()
fig.savefig("user_proc.pdf")

##plt.show()
